<?php
/**
 * This is the entrypoint for the locrMAPS WordPress plugin.
 *
 * @package locrMAPS
 */

declare(strict_types=1);

namespace Locr\WordPress\Plugin\LocrMaps\Api;

use Locr\WordPress\Plugin\LocrMaps\DDD\Entities\Icon;
use Locr\WordPress\Plugin\LocrMaps\DDD\Repositories\Icons as IconsRepository;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * This class is responsible for the shortcode.
 */
final class Icons {
	/**
	 * This function registers the all options route.
	 */
	public static function register_all_icons_route(): void {
		register_rest_route(
			route_namespace: 'locrmaps/icons',
			route: '/all',
			args: array(
				'methods'             => \WP_REST_Server::READABLE,
				'callback'            => function () {
					$response = array( 'icons' => array() );

					$icons_repository = new IconsRepository();
					$icons = $icons_repository->get_all_icons_as_associative();
					foreach ( $icons as $key => $icon ) {
						if ( ! ( $icon instanceof Icon ) ) {
							continue;
						}
						$icon_array = $icon->to_array();
						if ( isset( $icon_array['name'] ) ) {
							unset( $icon_array['name'] );
						}
						$response['icons'][ $key ] = $icon_array;
					}

					return rest_ensure_response( $response );
				},
				'permission_callback' => '__return_true',
			)
		);
	}
}
