<?php
/**
 * This is the entrypoint for the locrMAPS WordPress plugin.
 *
 * @package locrMAPS
 */

declare(strict_types=1);

namespace Locr\WordPress\Plugin\LocrMaps\Api;

use Locr\WordPress\Plugin\LocrMaps\DDD\Entities\OnlineMap;
use Locr\WordPress\Plugin\LocrMaps\DDD\Repositories\OnlineMaps as OnlineMapsRepository;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * This class is responsible for the ONLINEmaps
 */
final class OnlineMaps {
	/**
	 * This function registers the all onlinemaps route.
	 */
	public static function register_all_onlinemaps_route(): void {
		register_rest_route(
			route_namespace: 'locrmaps/onlinemaps',
			route: '/all',
			args: array(
				'methods'             => \WP_REST_Server::READABLE,
				'callback'            => function () {
					$response = array( 'onlinemaps' => array() );

					$onlinemaps_repository = new OnlineMapsRepository();
					$onlinemaps            = $onlinemaps_repository->get_all();
					foreach ( $onlinemaps as $key => $onlinemap ) {
						if ( ! ( $onlinemap instanceof OnlineMap ) ) {
							continue;
						}
						$response['onlinemaps'][ $key ] = $onlinemap->to_array();
					}

					return rest_ensure_response( $response );
				},
				'permission_callback' => '__return_true',
			)
		);
	}
}
